@@ -1,8 +1,8 @@
 from pydantic import BaseModel
 from models.PriceModel import Price
 from typing import List
-from models.ShippingProfileUpgradeModel import ShippingProfileUpgrade
-from models.ShippingProfileDestinationModel import ShippingProfileDestination
+from etsy_apiv3.models.ShippingProfileUpgradeModel import ShippingProfileUpgrade
+from etsy_apiv3.models.ShippingProfileDestinationModel import ShippingProfileDestination
 
 
 class ShippingProfile(BaseModel):
