@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 import json
 from typing import List, Optional
-from models.ListingPropertyModel import ListingProperty
-from utils.APIV3 import EtsyAuth
-from utils.Response import Response
-from models.ListingModel import Listing, Inventory
+from etsy_apiv3.models.ListingPropertyModel import ListingProperty
+from etsy_apiv3.utils.APIV3 import EtsyAuth
+from etsy_apiv3.utils.Response import Response
+from etsy_apiv3.models.ListingModel import Listing, Inventory
 
 @dataclass
 class ListingResource:
@@ -109,4 +109,4 @@ class ListingResource:
         endpoint = f"listings/{listing_id}/inventory"
 
         response = self.auth.request(endpoint, "PUT", data=json.dumps(data))
-        return Inventory(**response)
\ No newline at end of file
+        return Inventory(**response)
