@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from typing import Callable
+import requests
 from requests_oauthlib import OAuth2Session
 from etsy_apiv3.utils.RequestException import EtsyRequestException
 
@@ -35,12 +36,20 @@ class EtsyAuth:
             json: Json From Request Response
         """
 
+        headers = kwargs.get("headers", None)
+        if headers:
+            kwargs.pop("headers")
+        else:
+            headers = self.headers
+            
         url = f"{self.__base_endpoint}/{endpoint}"
-        req = self.session.request(method, url, headers=self.headers, *args, **kwargs)
-
+        req: requests.Response = self.session.request(method, url, headers=headers, *args, **kwargs)
+        
         response: dict = req.json()
+        
         if "error" in response.keys():
             raise EtsyRequestException(req.status_code, response["error"])
+        
         return response
 
 
